@@ -6,6 +6,6 @@ class Image(RESTModel):
 
     endpoint = "/image"
 
-    @property
-    def pk(self):
-        return getattr(self, 'name', None)
\ No newline at end of file
+    @classmethod
+    def _pk_key(cls):
+        return 'name'
\ No newline at end of file
